/* This file fixes the New Wave Firefox/Thinderbird issue with unreadable text in the menubar
 *
 * Created by Anton Kerezov <ankere@gmail.com>
 * 
 * Feel free to modify and share 
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to XUL */



/*make the menubar use gray color for text*/
menubar > menu {
   color: #E5E5E5  !important; 
}
/*make the menu use white color for text on mouse over*/
menubar > menu:hover {
  color: white;
}

/* use black for the prelight state */
menubar > menu[_moz-menuactive="true"][open="true"] {
  color: black !important;
}

/* Make the statusbar use grey color for text.
 * This improves usability.
 */
statusbar
{
	font-weight: normal !important;
   	color: rgb(50%,50%,50%) !important;
}


